@@ -1,4 +1,4 @@
-//@line 37 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/base/content/aboutDialog.js"
+//@line 37 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/base/content/aboutDialog.js"
 
 var gSelectedPage = 0;
 
@@ -38,8 +38,13 @@ function init(aEvent)
   button.setAttribute("accesskey", document.documentElement.getAttribute("creditsaccesskey"));
   button.addEventListener("command", switchPage, false);
 
-  document.documentElement.getButton("accept").focus();
-//@line 82 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/base/content/aboutDialog.js"
+  var acceptButton = document.documentElement.getButton("accept");
+//@line 78 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/base/content/aboutDialog.js"
+  acceptButton.setAttribute("icon", "close");
+//@line 80 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/base/content/aboutDialog.js"
+  acceptButton.focus();
+
+//@line 87 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/base/content/aboutDialog.js"
 }
 
 function uninit(aEvent)
