@@ -1,4 +1,4 @@
-//@line 42 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/base/content/pageinfo/pageInfo.js"
+//@line 42 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/base/content/pageinfo/pageInfo.js"
 
 //******** define a js object to implement nsITreeView
 function pageInfoTreeView(columnids, copycol)
@@ -148,10 +148,6 @@ var gImageHash = { };
 var gStrings = { };
 var gBundle;
 
-const DRAGSERVICE_CONTRACTID    = "@mozilla.org/widget/dragservice;1";
-const TRANSFERABLE_CONTRACTID   = "@mozilla.org/widget/transferable;1";
-const ARRAY_CONTRACTID          = "@mozilla.org/supports-array;1";
-const STRING_CONTRACTID         = "@mozilla.org/supports-string;1";
 const PERMISSION_CONTRACTID     = "@mozilla.org/permissionmanager;1";
 const PREFERENCES_CONTRACTID    = "@mozilla.org/preferences-service;1";
 const ATOM_CONTRACTID           = "@mozilla.org/atom-service;1";
@@ -222,7 +218,7 @@ var onProcessFrame = [ ];
 var onProcessElement = [ ];
 
 // These functions are called once when all the elements in all of the target
-// document (and all of it's subframes, if any) have been processed
+// document (and all of its subframes, if any) have been processed
 var onFinished = [ ];
 
 // These functions are called once when the Page Info window is closed.
@@ -277,6 +273,9 @@ function onLoadPageInfo()
   radioGroup.selectedItem = initialTab;
   radioGroup.selectedItem.doCommand();
   radioGroup.focus();
+  Components.classes["@mozilla.org/observer-service;1"]
+            .getService(Components.interfaces.nsIObserverService)
+            .notifyObservers(window, "page-info-dialog-loaded", null);
 }
 
 function loadPageInfo()
@@ -308,9 +307,9 @@ function resetPageInfo()
   /* Reset Media tab */
   var mediaTab = document.getElementById("mediaTab");
   if (!mediaTab.hidden) {
-    var os = Components.classes["@mozilla.org/observer-service;1"]
-                       .getService(Components.interfaces.nsIObserverService);
-    os.removeObserver(imagePermissionObserver, "perm-changed");
+    Components.classes["@mozilla.org/observer-service;1"]
+              .getService(Components.interfaces.nsIObserverService)
+              .removeObserver(imagePermissionObserver, "perm-changed");
     mediaTab.hidden = true;
   }
   gImageView.clear();
@@ -330,10 +329,11 @@ function resetPageInfo()
 
 function onUnloadPageInfo()
 {
+  // Remove the observer, only if there is at least 1 image.
   if (!document.getElementById("mediaTab").hidden) {
-    var os = Components.classes["@mozilla.org/observer-service;1"]
-                       .getService(Components.interfaces.nsIObserverService);
-    os.removeObserver(imagePermissionObserver, "perm-changed");
+    Components.classes["@mozilla.org/observer-service;1"]
+              .getService(Components.interfaces.nsIObserverService)
+              .removeObserver(imagePermissionObserver, "perm-changed");
   }
 
   /* Call registered overlay unload functions */
@@ -502,6 +502,7 @@ function doGrab(iterator)
       processFrames();
       return;
     }
+
   setTimeout(doGrab, 16, iterator);
 }
 
@@ -517,6 +518,7 @@ function addImage(url, type, alt, elem, isBg)
 {
   if (!url)
     return;
+
   if (!gImageHash.hasOwnProperty(url))
     gImageHash[url] = { };
   if (!gImageHash[url].hasOwnProperty(type))
@@ -544,11 +546,13 @@ function addImage(url, type, alt, elem, isBg)
     else
       sizeText = gStrings.unknown;
     gImageView.addRow([url, type, sizeText, alt, 1, elem, isBg]);
+
+    // Add the observer, only once.
     if (gImageView.data.length == 1) {
       document.getElementById("mediaTab").hidden = false;
-      var os = Components.classes["@mozilla.org/observer-service;1"]
-                         .getService(Components.interfaces.nsIObserverService);
-      os.addObserver(imagePermissionObserver, "perm-changed", false);
+      Components.classes["@mozilla.org/observer-service;1"]
+                .getService(Components.interfaces.nsIObserverService)
+                .addObserver(imagePermissionObserver, "perm-changed", false);
     }
   }
   else {
@@ -569,7 +573,7 @@ function grabAll(elem)
   if (elem instanceof HTMLImageElement)
     addImage(elem.src, gStrings.mediaImg,
              (elem.hasAttribute("alt")) ? elem.alt : gStrings.notSet, elem, false);
-//@line 613 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/base/content/pageinfo/pageInfo.js"
+//@line 617 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/base/content/pageinfo/pageInfo.js"
   else if (elem instanceof SVGImageElement) {
     try {
       // Note: makeURLAbsolute will throw if either the baseURI is not a valid URI
@@ -578,7 +582,7 @@ function grabAll(elem)
       addImage(href, gStrings.mediaImg, "", elem, false);
     } catch (e) { }
   }
-//@line 622 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/base/content/pageinfo/pageInfo.js"
+//@line 626 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/base/content/pageinfo/pageInfo.js"
   else if (elem instanceof HTMLLinkElement) {
     if (elem.rel && /\bicon\b/i.test(elem.rel))
       addImage(elem.href, gStrings.mediaLink, "", elem, false);
@@ -618,31 +622,16 @@ function onBeginLinkDrag(event,urlField,descField)
   if (row == -1)
     return;
 
-  // Getting drag-system needed services
-  var dragService = Components.classes[DRAGSERVICE_CONTRACTID].getService()
-                              .QueryInterface(Components.interfaces.nsIDragService);
-  var transArray = Components.classes[ARRAY_CONTRACTID]
-                             .createInstance(Components.interfaces.nsISupportsArray);
-  if (!transArray)
-    return;
-  var trans = Components.classes[TRANSFERABLE_CONTRACTID]
-                        .createInstance(Components.interfaces.nsITransferable);
-  if (!trans)
-    return;
-
   // Adding URL flavor
-  trans.addDataFlavor("text/x-moz-url");
   var col = tree.columns[urlField];
   var url = tree.view.getCellText(row, col);
   col = tree.columns[descField];
   var desc = tree.view.getCellText(row, col);
-  var stringURL = Components.classes[STRING_CONTRACTID]
-                            .createInstance(Components.interfaces.nsISupportsString);
-  stringURL.data = url + "\n" + desc;
-  trans.setTransferData("text/x-moz-url", stringURL, stringURL.data.length * 2 );
-  transArray.AppendElement(trans.QueryInterface(Components.interfaces.nsISupports));
 
-  dragService.invokeDragSession(event.target, transArray, null, dragService.DRAGDROP_ACTION_NONE);
+  var dt = event.dataTransfer;
+  dt.setData("text/x-moz-url", url + "\n" + desc);
+  dt.setData("text/url-list", url);
+  dt.setData("text/plain", url);
 }
 
 //******** Image Stuff
@@ -790,9 +779,9 @@ function makePreview(row)
 
   var imageText;
   if (!isBG &&
-//@line 834 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/base/content/pageinfo/pageInfo.js"
+//@line 823 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/base/content/pageinfo/pageInfo.js"
       !(item instanceof SVGImageElement) &&
-//@line 836 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/base/content/pageinfo/pageInfo.js"
+//@line 825 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/base/content/pageinfo/pageInfo.js"
       !(gDocument instanceof ImageDocument)) {
     imageText = item.title || item.alt;
 
@@ -836,7 +825,7 @@ function makePreview(row)
       item instanceof HTMLLinkElement)
     mimeType = item.type;
 
-  if (!mimeType && item instanceof nsIImageLoadingContent) {
+  if (!mimeType && !isBG && item instanceof nsIImageLoadingContent) {
     var imageRequest = item.getRequest(nsIImageLoadingContent.CURRENT_REQUEST);
     if (imageRequest) {
       mimeType = imageRequest.mimeType;
@@ -848,23 +837,28 @@ function makePreview(row)
   if (!mimeType)
     mimeType = getContentTypeFromHeaders(cacheEntryDescriptor);
 
+  var imageType;
   if (mimeType) {
     // We found the type, try to display it nicely
     var imageMimeType = /^image\/(.*)/.exec(mimeType);
     if (imageMimeType) {
-      mimeType = imageMimeType[1].toUpperCase();
+      imageType = imageMimeType[1].toUpperCase();
       if (numFrames > 1)
-        mimeType = gBundle.getFormattedString("mediaAnimatedImageType",
-                                              [mimeType, numFrames]);
+        imageType = gBundle.getFormattedString("mediaAnimatedImageType",
+                                               [imageType, numFrames]);
       else
-        mimeType = gBundle.getFormattedString("mediaImageType", [mimeType]);
+        imageType = gBundle.getFormattedString("mediaImageType", [imageType]);
+    }
+    else {
+      // the MIME type doesn't begin with image/, display the raw type
+      imageType = mimeType;
     }
   }
   else {
     // We couldn't find the type, fall back to the value in the treeview
-    mimeType = gImageView.data[row][COL_IMAGE_TYPE];
+    imageType = gImageView.data[row][COL_IMAGE_TYPE];
   }
-  setItemValue("imagetypetext", mimeType);
+  setItemValue("imagetypetext", imageType);
 
   var imageContainer = document.getElementById("theimagecontainer");
   var oldImage = document.getElementById("thepreviewimage");
@@ -881,9 +875,9 @@ function makePreview(row)
 
   if ((item instanceof HTMLLinkElement || item instanceof HTMLInputElement ||
        item instanceof HTMLImageElement ||
-//@line 925 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/base/content/pageinfo/pageInfo.js"
+//@line 919 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/base/content/pageinfo/pageInfo.js"
        item instanceof SVGImageElement ||
-//@line 927 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/base/content/pageinfo/pageInfo.js"
+//@line 921 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/base/content/pageinfo/pageInfo.js"
       (item instanceof HTMLObjectElement && /^image\//.test(mimeType)) || isBG) && isProtocolAllowed) {
     newImage.setAttribute("src", url);
     physWidth = newImage.width || 0;
@@ -903,12 +897,12 @@ function makePreview(row)
       newImage.height = newImage.naturalHeight;
     }
 
-//@line 947 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/base/content/pageinfo/pageInfo.js"
+//@line 941 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/base/content/pageinfo/pageInfo.js"
     if (item instanceof SVGImageElement) {
       newImage.width = item.width.baseVal.value;
       newImage.height = item.height.baseVal.value;
     }
-//@line 952 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/base/content/pageinfo/pageInfo.js"
+//@line 946 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/base/content/pageinfo/pageInfo.js"
 
     width = newImage.width;
     height = newImage.height;
@@ -977,6 +971,7 @@ var imagePermissionObserver = {
   {
     if (document.getElementById("mediaPreviewBox").collapsed)
       return;
+
     if (aTopic == "perm-changed") {
       var permission = aSubject.QueryInterface(Components.interfaces.nsIPermission);
       if (permission.type == "image") {
@@ -1079,7 +1074,7 @@ function formatNumber(number)
 
 function formatDate(datestr, unknown)
 {
-  // scriptable date formater, for pretty printing dates
+  // scriptable date formatter, for pretty printing dates
   var dateService = Components.classes["@mozilla.org/intl/scriptabledateformat;1"]
                               .getService(Components.interfaces.nsIScriptableDateFormat);
 
