@@ -1,4 +1,4 @@
-//@line 40 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/components/places/content/history-panel.js"
+//@line 40 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/components/places/content/history-panel.js"
 
 var gHistoryTree;
 var gSearchBox;
@@ -39,8 +39,7 @@ function initContextMenu() {
 function GroupBy(groupingType)
 {
   gHistoryGrouping = groupingType;
-  gSearchBox.value = "";
-  searchHistory("");
+  searchHistory(gSearchBox.value);
 }
 
 function historyAddBookmarks()
@@ -62,32 +61,33 @@ function searchHistory(aInput)
   var sortingMode;
   var resultType;
 
+  switch (gHistoryGrouping) {
+    case "visited":
+      resultType = NHQO.RESULTS_AS_URI;
+      sortingMode = NHQO.SORT_BY_VISITCOUNT_DESCENDING;
+      break; 
+    case "lastvisited":
+      resultType = NHQO.RESULTS_AS_URI;
+      sortingMode = NHQO.SORT_BY_DATE_DESCENDING;
+      break; 
+    case "dayandsite":
+      resultType = NHQO.RESULTS_AS_DATE_SITE_QUERY;
+      break;
+    case "site":
+      resultType = NHQO.RESULTS_AS_SITE_QUERY;
+      sortingMode = NHQO.SORT_BY_TITLE_ASCENDING;
+      break;
+    case "day":
+    default:
+      resultType = NHQO.RESULTS_AS_DATE_QUERY;
+      break;
+  }
+
   if (aInput) {
     query.searchTerms = aInput;
-    sortingMode = NHQO.SORT_BY_TITLE_ASCENDING;
-    resultType = NHQO.RESULTS_AS_URI;
-  }
-  else {
-    switch (gHistoryGrouping) {
-      case "visited":
-        resultType = NHQO.RESULTS_AS_URI;
-        sortingMode = NHQO.SORT_BY_VISITCOUNT_DESCENDING;
-        break; 
-      case "lastvisited":
-        resultType = NHQO.RESULTS_AS_URI;
-        sortingMode = NHQO.SORT_BY_DATE_DESCENDING;
-        break; 
-      case "dayandsite":
-        resultType = NHQO.RESULTS_AS_DATE_SITE_QUERY;
-        break;
-      case "site":
-        resultType = NHQO.RESULTS_AS_SITE_QUERY;
-        sortingMode = NHQO.SORT_BY_TITLE_ASCENDING;
-        break;
-      case "day":
-      default:
-        resultType = NHQO.RESULTS_AS_DATE_QUERY;
-        break;
+    if (gHistoryGrouping != "visited" && gHistoryGrouping != "lastvisited") {
+      sortingMode = NHQO.SORT_BY_TITLE_ASCENDING;
+      resultType = NHQO.RESULTS_AS_URI;
     }
   }
 
