@@ -1,4 +1,4 @@
-//@line 36 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/browser/components/safebrowsing/content/sb-loader.js"
+//@line 36 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/browser/components/safebrowsing/content/sb-loader.js"
 
 var safebrowsing = {
   appContext: null,
@@ -15,12 +15,29 @@ var safebrowsing = {
   },
 
   setReportPhishingMenu: function() {
+      
+    // A phishing page will have a specific about:blocked content documentURI
+    var isPhishingPage = /^about:blocked\?e=phishingBlocked/.test(content.document.documentURI);
+    
+    // Show/hide the appropriate menu item.
+    document.getElementById("menu_HelpPopup_reportPhishingtoolmenu")
+            .hidden = isPhishingPage;
+    document.getElementById("menu_HelpPopup_reportPhishingErrortoolmenu")
+            .hidden = !isPhishingPage;
+
+    var broadcasterId = isPhishingPage
+                        ? "reportPhishingErrorBroadcaster"
+                        : "reportPhishingBroadcaster";
+
+    var broadcaster = document.getElementById(broadcasterId);
+    if (!broadcaster)
+      return;
+
     var uri = getBrowser().currentURI;
-    var broadcaster = document.getElementById("reportPhishingBroadcaster");
     if (uri && (uri.schemeIs("http") || uri.schemeIs("https")))
       broadcaster.removeAttribute("disabled");
     else
-      broadcaster.disabled = true;
+      broadcaster.setAttribute("disabled", true);
   },
   
   /**
@@ -34,7 +51,7 @@ var safebrowsing = {
 
   /**
    * Used to report a phishing page or a false positive
-   * @param name String either "Phish" or "Error"
+   * @param name String One of "Phish", "Error", "Malware" or "MalwareError"
    * @return String the report phishing URL.
    */
   getReportURL: function(name) {
