@@ -1,6 +1,6 @@
 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
-//@line 40 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/toolkit/mozapps/extensions/src/nsBlocklistService.js"
+//@line 41 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/toolkit/mozapps/extensions/src/nsBlocklistService.js"
 */
 
 const Cc = Components.classes;
@@ -16,6 +16,7 @@ const FILE_BLOCKLIST                  = "blocklist.xml";
 const PREF_BLOCKLIST_URL              = "extensions.blocklist.url";
 const PREF_BLOCKLIST_ENABLED          = "extensions.blocklist.enabled";
 const PREF_BLOCKLIST_INTERVAL         = "extensions.blocklist.interval";
+const PREF_BLOCKLIST_LEVEL            = "extensions.blocklist.level";
 const PREF_GENERAL_USERAGENT_LOCALE   = "general.useragent.locale";
 const PREF_PARTNER_BRANCH             = "app.partner.";
 const PREF_APP_DISTRIBUTION           = "distribution.id";
@@ -25,6 +26,10 @@ const PREF_EM_LOGGING_ENABLED         = "extensions.logging.enabled";
 const XMLURI_BLOCKLIST                = "http://www.mozilla.org/2006/addons-blocklist";
 const XMLURI_PARSE_ERROR              = "http://www.mozilla.org/newlayout/xml/parsererror.xml"
 const UNKNOWN_XPCOM_ABI               = "unknownABI";
+const URI_BLOCKLIST_DIALOG            = "chrome://mozapps/content/extensions/blocklist.xul"
+const DEFAULT_SEVERITY                = 3;
+const DEFAULT_LEVEL                   = 2;
+const MAX_BLOCK_LEVEL                 = 3;
 
 const MODE_RDONLY   = 0x01;
 const MODE_WRONLY   = 0x02;
@@ -43,9 +48,11 @@ var gVersionChecker = null;
 var gLoggingEnabled = null;
 var gABI = null;
 var gOSVersion = null;
+var gBlocklistEnabled = true;
+var gBlocklistLevel = DEFAULT_LEVEL;
 
 // shared code for suppressing bad cert dialogs
-//@line 40 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/toolkit/mozapps/shared/src/badCertHandler.js"
+//@line 41 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/toolkit/mozapps/shared/src/badCertHandler.js"
 
 /**
  * Only allow built-in certs for HTTPS connections.  See bug 340198.
@@ -65,12 +72,23 @@ function checkCert(channel) {
     issuer = cert.issuer;
   }
 
-  if (!issuer || issuer.tokenName != "Builtin Object Token")
-    throw "cert issuer is not built-in";
+  var errorstring = "cert issuer is not built-in";
+  if (!issuer)
+    throw errorstring;
+
+  issuer = issuer.QueryInterface(Ci.nsIX509Cert3);
+  var tokenNames = issuer.getAllTokenNames({});
+
+  if (!tokenNames.some(isBuiltinToken))
+    throw errorstring;
+}
+
+function isBuiltinToken(tokenName) {
+  return tokenName == "Builtin Object Token";
 }
 
 /**
- * This class implements nsIBadCertListener.  It's job is to prevent "bad cert"
+ * This class implements nsIBadCertListener.  Its job is to prevent "bad cert"
  * security dialogs from being shown to the user.  It is better to simply fail
  * if the certificate is bad. See bug 304286.
  */
@@ -111,7 +129,7 @@ BadCertHandler.prototype = {
     return this;
   }
 };
-//@line 85 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/toolkit/mozapps/extensions/src/nsBlocklistService.js"
+//@line 93 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/toolkit/mozapps/extensions/src/nsBlocklistService.js"
 
 /**
  * Logs a string to the error console.
@@ -216,10 +234,28 @@ function newURI(spec) {
   return ioServ.newURI(spec, null, null);
 }
 
+// Restarts the application checking in with observers first
+function restartApp() {
+  // Notify all windows that an application quit has been requested.
+  var os = Cc["@mozilla.org/observer-service;1"].
+           getService(Ci.nsIObserverService);
+  var cancelQuit = Cc["@mozilla.org/supports-PRBool;1"].
+                   createInstance(Ci.nsISupportsPRBool);
+  os.notifyObservers(cancelQuit, "quit-application-requested", null);
+
+  // Something aborted the quit process. 
+  if (cancelQuit.data)
+    return;
+
+  var as = Cc["@mozilla.org/toolkit/app-startup;1"].
+           getService(Ci.nsIAppStartup);
+  as.quit(Ci.nsIAppStartup.eRestart | Ci.nsIAppStartup.eAttemptQuit);
+}
+
 /**
  * Checks whether this blocklist element is valid for the current OS and ABI.
  * If the element has an "os" attribute then the current OS must appear in
- * it's comma separated list for the element to be valid. Similarly for the
+ * its comma separated list for the element to be valid. Similarly for the
  * xpcomabi attribute.
  */
 function matchesOSABI(blocklistElement) {
@@ -246,9 +282,7 @@ function matchesOSABI(blocklistElement) {
 function getLocale() {
   try {
       // Get the default branch
-      var prefs = Components.classes["@mozilla.org/preferences-service;1"]
-          .getService(Components.interfaces.nsIPrefService);
-      var defaultPrefs = prefs.getDefaultBranch(null);
+      var defaultPrefs = gPref.getDefaultBranch(null);
       return defaultPrefs.getCharPref(PREF_GENERAL_USERAGENT_LOCALE);
   } catch (e) {}
 
@@ -265,9 +299,7 @@ function getUpdateChannel() {
   var prefName;
   var prefValue;
 
-  var defaults =
-      gPref.QueryInterface(Components.interfaces.nsIPrefService).
-      getDefaultBranch(null);
+  var defaults = gPref.getDefaultBranch(null);
   try {
     channel = defaults.getCharPref(PREF_APP_UPDATE_CHANNEL);
   } catch (e) {
@@ -297,9 +329,7 @@ function getUpdateChannel() {
 function getDistributionPrefValue(aPrefName) {
   var prefValue = "default";
 
-  var defaults =
-      gPref.QueryInterface(Components.interfaces.nsIPrefService).
-      getDefaultBranch(null);
+  var defaults = gPref.getDefaultBranch(null);
   try {
     prefValue = defaults.getCharPref(aPrefName);
   } catch (e) {
@@ -320,7 +350,8 @@ function Blocklist() {
   gApp = Cc["@mozilla.org/xre/app-info;1"].getService(Ci.nsIXULAppInfo);
   gApp.QueryInterface(Ci.nsIXULRuntime);
   gPref = Cc["@mozilla.org/preferences-service;1"].
-          getService(Ci.nsIPrefBranch2);
+          getService(Ci.nsIPrefService).
+          QueryInterface(Ci.nsIPrefBranch2);
   gVersionChecker = Cc["@mozilla.org/xpcom/version-comparator;1"].
                     getService(Ci.nsIVersionComparator);
   gConsole = Cc["@mozilla.org/consoleservice;1"].
@@ -359,7 +390,7 @@ function Blocklist() {
     gOSVersion = encodeURIComponent(osVersion);
   }
 
-//@line 341 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/toolkit/mozapps/extensions/src/nsBlocklistService.js"
+//@line 362 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/toolkit/mozapps/extensions/src/nsBlocklistService.js"
 }
 
 Blocklist.prototype = {
@@ -383,79 +414,99 @@ Blocklist.prototype = {
 
   observe: function (aSubject, aTopic, aData) {
     switch (aTopic) {
-    case "app-startup":
-      gOS.addObserver(this, "plugins-list-updated", false);
-      gOS.addObserver(this, "profile-after-change", false);
-      gOS.addObserver(this, "quit-application", false);
-      break;
     case "profile-after-change":
       gLoggingEnabled = getPref("getBoolPref", PREF_EM_LOGGING_ENABLED, false);
+      gBlocklistEnabled = getPref("getBoolPref", PREF_BLOCKLIST_ENABLED, true);
+      gBlocklistLevel = Math.min(getPref("getIntPref", PREF_BLOCKLIST_LEVEL, DEFAULT_LEVEL),
+                                 MAX_BLOCK_LEVEL);
+      gPref.addObserver("extensions.blocklist.", this, false);
       var tm = Cc["@mozilla.org/updates/timer-manager;1"].
                getService(Ci.nsIUpdateTimerManager);
       var interval = getPref("getIntPref", PREF_BLOCKLIST_INTERVAL, 86400);
       tm.registerTimer("blocklist-background-update-timer", this, interval);
       break;
-    case "plugins-list-updated":
-      this._checkPluginsList();
-      break;
-    case "quit-application":
-      gOS.removeObserver(this, "plugins-list-updated");
-      gOS.removeObserver(this, "profile-after-change");
-      gOS.removeObserver(this, "quit-application");
-      break;
     case "xpcom-shutdown":
       gOS.removeObserver(this, "xpcom-shutdown");
       gOS = null;
+      gPref.removeObserver("extensions.blocklist.", this);
       gPref = null;
       gConsole = null;
       gVersionChecker = null;
       gApp = null;
       break;
+    case "nsPref:changed":
+      switch (aData) {
+        case PREF_BLOCKLIST_ENABLED:
+          gBlocklistEnabled = getPref("getBoolPref", PREF_BLOCKLIST_ENABLED, true);
+          this._loadBlocklist();
+          this._blocklistUpdated(null, null);
+          break;
+        case PREF_BLOCKLIST_LEVEL:
+          gBlocklistLevel = Math.min(getPref("getIntPref", PREF_BLOCKLIST_LEVEL, DEFAULT_LEVEL),
+                                     MAX_BLOCK_LEVEL);
+          this._blocklistUpdated(null, null);
+          break;
+      }
+      break;
     }
   },
 
+  /* See nsIBlocklistService */
   isAddonBlocklisted: function(id, version, appVersion, toolkitVersion) {
+    return this.getAddonBlocklistState(id, version, appVersion, toolkitVersion) ==
+                   Ci.nsIBlocklistService.STATE_BLOCKED;
+  },
+
+  /* See nsIBlocklistService */
+  getAddonBlocklistState: function(id, version, appVersion, toolkitVersion) {
     if (!this._addonEntries)
       this._loadBlocklist();
+    return this._getAddonBlocklistState(id, version, this._addonEntries,
+                                        appVersion, toolkitVersion);
+  },
+
+  /**
+   * Private version of getAddonBlocklistState that allows the caller to pass in
+   * the add-on blocklist entries to compare against.
+   *
+   * @param   id
+   *          The ID of the item to get the blocklist state for.
+   * @param   version
+   *          The version of the item to get the blocklist state for.
+   * @param   addonEntries
+   *          The add-on blocklist entries to compare against.
+   * @param   appVersion
+   *          The application version to compare to, will use the current
+   *          version if null.
+   * @param   toolkitVersion
+   *          The toolkit version to compare to, will use the current version if
+   *          null.
+   * @returns The blocklist state for the item, one of the STATE constants as
+   *          defined in nsIBlocklistService.
+   */
+  _getAddonBlocklistState: function(id, version, addonEntries, appVersion, toolkitVersion) {
+    if (!gBlocklistEnabled)
+      return Ci.nsIBlocklistService.STATE_NOT_BLOCKED;
+
     if (!appVersion)
       appVersion = gApp.version;
     if (!toolkitVersion)
       toolkitVersion = gApp.platformVersion;
 
-    var blItem = this._addonEntries[id];
+    var blItem = addonEntries[id];
     if (!blItem)
-      return false;
+      return Ci.nsIBlocklistService.STATE_NOT_BLOCKED;
 
     for (var i = 0; i < blItem.length; ++i) {
-      if (gVersionChecker.compare(version, blItem[i].minVersion) < 0  ||
-          gVersionChecker.compare(version, blItem[i].maxVersion) > 0)
-        continue;
-
-      var blTargetApp = blItem[i].targetApps[gApp.ID];
-      if (blTargetApp) {
-        for (var x = 0; x < blTargetApp.length; ++x) {
-          if (gVersionChecker.compare(appVersion, blTargetApp[x].minVersion) < 0 ||
-              gVersionChecker.compare(appVersion, blTargetApp[x].maxVersion) > 0)
-            continue;
-          return true;
-        }
-      }
-
-      blTargetApp = blItem[i].targetApps[TOOLKIT_ID];
-      if (!blTargetApp)
-        return false;
-      for (x = 0; x < blTargetApp.length; ++x) {
-        if (gVersionChecker.compare(toolkitVersion, blTargetApp[x].minVersion) < 0 ||
-            gVersionChecker.compare(toolkitVersion, blTargetApp[x].maxVersion) > 0)
-          continue;
-        return true;
-      }
+      if (blItem[i].includesItem(version, appVersion, toolkitVersion))
+        return blItem[i].severity >= gBlocklistLevel ? Ci.nsIBlocklistService.STATE_BLOCKED :
+                                                       Ci.nsIBlocklistService.STATE_SOFTBLOCKED;
     }
-    return false;
+    return Ci.nsIBlocklistService.STATE_NOT_BLOCKED;
   },
 
   notify: function(aTimer) {
-    if (getPref("getBoolPref", PREF_BLOCKLIST_ENABLED, true) == false)
+    if (!gBlocklistEnabled)
       return;
 
     try {
@@ -505,6 +556,11 @@ Blocklist.prototype = {
     request.onerror = function(event) { self.onXMLError(event); };
     request.onload  = function(event) { self.onXMLLoad(event);  };
     request.send(null);
+
+    // When the blocklist loads we need to compare it to the current copy so
+    // make sure we have loaded it.
+    if (!this._addonEntries)
+      this._loadBlocklist();
   },
 
   onXMLLoad: function(aEvent) {
@@ -528,11 +584,14 @@ Blocklist.prototype = {
     var fos = openSafeFileOutputStream(blocklistFile);
     fos.write(request.responseText, request.responseText.length);
     closeSafeFileOutputStream(fos);
+
+    var oldAddonEntries = this._addonEntries;
+    var oldPluginEntries = this._pluginEntries;
+    this._addonEntries = { };
+    this._pluginEntries = { };
     this._loadBlocklistFromFile(getFile(KEY_PROFILEDIR, [FILE_BLOCKLIST]));
-    var em = Cc["@mozilla.org/extensions/manager;1"].
-             getService(Ci.nsIExtensionManager);
-    em.checkForBlocklistChanges();
-    this._checkPluginsList();
+
+    this._blocklistUpdated(oldAddonEntries, oldPluginEntries);
   },
 
   onXMLError: function(aEvent) {
@@ -574,11 +633,11 @@ Blocklist.prototype = {
   },
 
   /**
-//@line 604 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/toolkit/mozapps/extensions/src/nsBlocklistService.js"
+//@line 653 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/toolkit/mozapps/extensions/src/nsBlocklistService.js"
    */
 
   _loadBlocklistFromFile: function(file) {
-    if (getPref("getBoolPref", PREF_BLOCKLIST_ENABLED, true) == false) {
+    if (!gBlocklistEnabled) {
       LOG("Blocklist::_loadBlocklistFromFile: blocklist is disabled");
       return;
     }
@@ -604,7 +663,7 @@ Blocklist.prototype = {
 
       var childNodes = doc.documentElement.childNodes;
       this._addonEntries = this._processItemNodes(childNodes, "em",
-                                            this._handleEmItemNode);
+                                                  this._handleEmItemNode);
       this._pluginEntries = this._processItemNodes(childNodes, "plugin",
                                                    this._handlePluginItemNode);
     }
@@ -668,48 +727,174 @@ Blocklist.prototype = {
       return;
 
     var matchNodes = blocklistElement.childNodes;
-    var matchList;
+    var blockEntry = {
+      matches: {},
+      versions: []
+    };
     for (var x = 0; x < matchNodes.length; ++x) {
       var matchElement = matchNodes.item(x);
-      if (!(matchElement instanceof Ci.nsIDOMElement) ||
-          matchElement.localName != "match")
+      if (!(matchElement instanceof Ci.nsIDOMElement))
         continue;
-
-      var name = matchElement.getAttribute("name");
-      var exp = matchElement.getAttribute("exp");
-      if (!matchList)
-        matchList = { };
-      matchList[name] = new RegExp(exp, "m");
+      if (matchElement.localName == "match") {
+        var name = matchElement.getAttribute("name");
+        var exp = matchElement.getAttribute("exp");
+        blockEntry.matches[name] = new RegExp(exp, "m");
+      }
+      if (matchElement.localName == "versionRange")
+        blockEntry.versions.push(new BlocklistItemData(matchElement));
     }
-    if (matchList)
-      result.push(matchList);
+    // Add a default versionRange if there wasn't one specified
+    if (blockEntry.versions.length == 0)
+      blockEntry.versions.push(new BlocklistItemData(null));
+    result.push(blockEntry);
   },
 
-  _checkPlugin: function(plugin) {
-    for each (var matchList in this._pluginEntries) {
+  /* See nsIBlocklistService */
+  getPluginBlocklistState: function(plugin, appVersion, toolkitVersion) {
+    if (!this._pluginEntries)
+      this._loadBlocklist();
+    return this._getPluginBlocklistState(plugin, this._pluginEntries,
+                                         appVersion, toolkitVersion);
+  },
+
+  /**
+   * Private version of getPluginBlocklistState that allows the caller to pass in
+   * the plugin blocklist entries.
+   *
+   * @param   plugin
+   *          The nsIPluginTag to get the blocklist state for.
+   * @param   pluginEntries
+   *          The plugin blocklist entries to compare against.
+   * @param   appVersion
+   *          The application version to compare to, will use the current
+   *          version if null.
+   * @param   toolkitVersion
+   *          The toolkit version to compare to, will use the current version if
+   *          null.
+   * @returns The blocklist state for the item, one of the STATE constants as
+   *          defined in nsIBlocklistService.
+   */
+  _getPluginBlocklistState: function(plugin, pluginEntries, appVersion, toolkitVersion) {
+    if (!gBlocklistEnabled)
+      return Ci.nsIBlocklistService.STATE_NOT_BLOCKED;
+
+    if (!appVersion)
+      appVersion = gApp.version;
+    if (!toolkitVersion)
+      toolkitVersion = gApp.platformVersion;
+
+    for each (var blockEntry in pluginEntries) {
       var matchFailed = false;
-      for (var name in matchList) {
-        if (typeof(plugin[name]) != "string" ||
-            !matchList[name].test(plugin[name])) {
+      for (var name in blockEntry.matches) {
+        if (!(name in plugin) ||
+            typeof(plugin[name]) != "string" ||
+            !blockEntry.matches[name].test(plugin[name])) {
           matchFailed = true;
           break;
         }
       }
 
-      if (!matchFailed) {
-        plugin.blocklisted = true;
-        return;
+      if (matchFailed)
+        continue;
+
+      for (var i = 0; i < blockEntry.versions.length; i++) {
+        if (blockEntry.versions[i].includesItem(plugin.version, appVersion,
+                                                toolkitVersion))
+          return blockEntry.versions[i].severity >= gBlocklistLevel ?
+                                                    Ci.nsIBlocklistService.STATE_BLOCKED :
+                                                    Ci.nsIBlocklistService.STATE_SOFTBLOCKED;
       }
     }
-    plugin.blocklisted = false;
+
+    return Ci.nsIBlocklistService.STATE_NOT_BLOCKED;
   },
 
-  _checkPluginsList: function() {
-    if (!this._addonEntries)
-      this._loadBlocklist();
+  _blocklistUpdated: function(oldAddonEntries, oldPluginEntries) {
+    var addonList = [];
+
+    var em = Cc["@mozilla.org/extensions/manager;1"].
+             getService(Ci.nsIExtensionManager);
+    var addons = em.updateAndGetNewBlocklistedItems({});
+
+    for (let i = 0; i < addons.length; i++) {
+      let oldState = -1;
+      if (oldAddonEntries)
+        oldState = this._getAddonBlocklistState(addons[i].id, addons[i].version,
+                                                oldAddonEntries);
+      let state = this.getAddonBlocklistState(addons[i].id, addons[i].version);
+      // We don't want to re-warn about items
+      if (state == oldState)
+        continue;
+
+      addonList.push({
+        name: addons[i].name,
+        version: addons[i].version,
+        icon: addons[i].iconURL,
+        disable: false,
+        blocked: state == Ci.nsIBlocklistService.STATE_BLOCKED,
+        item: addons[i]
+      });
+    }
+
     var phs = Cc["@mozilla.org/plugin/host;1"].
               getService(Ci.nsIPluginHost);
-    phs.getPluginTags({ }).forEach(this._checkPlugin, this);
+    var plugins = phs.getPluginTags({});
+
+    for (let i = 0; i < plugins.length; i++) {
+      let oldState = -1;
+      if (oldPluginEntries)
+        oldState = this._getPluginBlocklistState(plugins[i], oldPluginEntries);
+      let state = this.getPluginBlocklistState(plugins[i]);
+      // We don't want to re-warn about items
+      if (state == oldState)
+        continue;
+
+      if (plugins[i].blocklisted) {
+        if (state == Ci.nsIBlocklistService.STATE_SOFTBLOCKED)
+          plugins[i].disabled = true;
+      }
+      else if (!plugins[i].disabled && state != Ci.nsIBlocklistService.STATE_NOT_BLOCKED) {
+        addonList.push({
+          name: plugins[i].name,
+          version: plugins[i].version,
+          icon: "chrome://mozapps/skin/plugins/pluginGeneric.png",
+          disable: false,
+          blocked: state == Ci.nsIBlocklistService.STATE_BLOCKED,
+          item: plugins[i]
+        });
+      }
+      plugins[i].blocklisted = state == Ci.nsIBlocklistService.STATE_BLOCKED;
+    }
+
+    if (addonList.length == 0)
+      return;
+
+    var args = {
+      restart: false,
+      list: addonList
+    };
+    // This lets the dialog get the raw js object
+    args.wrappedJSObject = args;
+
+    var ww = Cc["@mozilla.org/embedcomp/window-watcher;1"].
+             getService(Ci.nsIWindowWatcher);
+    ww.openWindow(null, URI_BLOCKLIST_DIALOG, "",
+                  "chrome,centerscreen,dialog,modal,titlebar", args);
+
+    for (let i = 0; i < addonList.length; i++) {
+      if (!addonList[i].disable)
+        continue;
+
+      if (addonList[i].item instanceof Ci.nsIUpdateItem)
+        em.disableItem(addonList[i].item.id);
+      else if (addonList[i].item instanceof Ci.nsIPluginTag)
+        addonList[i].item.disabled = true;
+      else
+        LOG("Unknown add-on type: " + addonList[i].item);
+    }
+
+    if (args.restart)
+      restartApp();
   },
 
   classDescription: "Blocklist Service",
@@ -718,10 +903,7 @@ Blocklist.prototype = {
   QueryInterface: XPCOMUtils.generateQI([Ci.nsIObserver,
                                          Ci.nsIBlocklistService,
                                          Ci.nsITimerCallback]),
-  _xpcom_categories: [{
-    category: "app-startup",
-    service: true
-  }]
+  _xpcom_categories: [{ category: "profile-after-change" }]
 };
 
 /**
@@ -731,6 +913,10 @@ function BlocklistItemData(versionRangeElement) {
   var versionRange = this.getBlocklistVersionRange(versionRangeElement);
   this.minVersion = versionRange.minVersion;
   this.maxVersion = versionRange.maxVersion;
+  if (versionRangeElement && versionRangeElement.hasAttribute("severity"))
+    this.severity = versionRangeElement.getAttribute("severity");
+  else
+    this.severity = DEFAULT_SEVERITY;
   this.targetApps = { };
   var found = false;
 
@@ -746,25 +932,97 @@ function BlocklistItemData(versionRangeElement) {
       this.targetApps[appID] = this.getBlocklistAppVersions(targetAppElement);
     }
   }
-  // Default to all versions of the extension and the current application when
-  // versionRange is not defined.
+  // Default to all versions of the current application when no targetApplication
+  // elements were found
   if (!found)
     this.targetApps[gApp.ID] = this.getBlocklistAppVersions(null);
 }
 
 BlocklistItemData.prototype = {
-/**
- * Retrieves a version range (e.g. minVersion and maxVersion) for a
- * blocklist item's targetApplication element.
- * @param   targetAppElement
- *          A targetApplication blocklist element.
- * @returns An array of JS objects with the following properties:
- *          "minVersion"  The minimum version in a version range (default = 0).
- *          "maxVersion"  The maximum version in a version range (default = *).
- */
+  /**
+   * Tests if a version of an item is included in the version range and target
+   * application information represented by this BlocklistItemData using the
+   * provided application and toolkit versions.
+   * @param   version
+   *          The version of the item being tested.
+   * @param   appVersion
+   *          The application version to test with.
+   * @param   toolkitVersion
+   *          The toolkit version to test with.
+   * @returns True if the version range covers the item version and application
+   *          or toolkit version.
+   */
+  includesItem: function(version, appVersion, toolkitVersion) {
+    // Some platforms have no version for plugins, these don't match if there
+    // was a min/maxVersion provided
+    if (!version && (this.minVersion || this.maxVersion))
+      return false;
+
+    // Check if the item version matches
+    if (!this.matchesRange(version, this.minVersion, this.maxVersion))
+      return false;
+
+    // Check if the application version matches
+    if (this.matchesTargetRange(gApp.ID, appVersion))
+      return true;
+
+    // Check if the toolkit version matches
+    return this.matchesTargetRange(TOOLKIT_ID, toolkitVersion);
+  },
+
+  /**
+   * Checks if a version is higher than or equal to the minVersion (if provided)
+   * and lower than or equal to the maxVersion (if provided).
+   * @param   version
+   *          The version to test.
+   * @param   minVersion
+   *          The minimum version. If null it is assumed that version is always
+   *          larger.
+   * @param   maxVersion
+   *          The maximum version. If null it is assumed that version is always
+   *          smaller.
+   */
+  matchesRange: function(version, minVersion, maxVersion) {
+    if (minVersion && gVersionChecker.compare(version, minVersion) < 0)
+      return false;
+    if (maxVersion && gVersionChecker.compare(version, maxVersion) > 0)
+      return false;
+    return true;
+  },
+
+  /**
+   * Tests if there is a matching range for the given target application id and
+   * version.
+   * @param   appID
+   *          The application ID to test for, may be for an application or toolkit
+   * @param   appVersion
+   *          The version of the application to test for.
+   * @returns True if this version range covers the application version given.
+   */
+  matchesTargetRange: function(appID, appVersion) {
+    var blTargetApp = this.targetApps[appID];
+    if (!blTargetApp)
+      return false;
+
+    for (var x = 0; x < blTargetApp.length; ++x) {
+      if (this.matchesRange(appVersion, blTargetApp[x].minVersion, blTargetApp[x].maxVersion))
+        return true;
+    }
+
+    return false;
+  },
+
+  /**
+   * Retrieves a version range (e.g. minVersion and maxVersion) for a
+   * blocklist item's targetApplication element.
+   * @param   targetAppElement
+   *          A targetApplication blocklist element.
+   * @returns An array of JS objects with the following properties:
+   *          "minVersion"  The minimum version in a version range (default = null).
+   *          "maxVersion"  The maximum version in a version range (default = null).
+   */
   getBlocklistAppVersions: function(targetAppElement) {
     var appVersions = [ ];
-    var found = false;
 
     if (targetAppElement) {
       for (var i = 0; i < targetAppElement.childNodes.length; ++i) {
@@ -772,28 +1030,28 @@ BlocklistItemData.prototype = {
         if (!(versionRangeElement instanceof Ci.nsIDOMElement) ||
             versionRangeElement.localName != "versionRange")
           continue;
-        found = true;
         appVersions.push(this.getBlocklistVersionRange(versionRangeElement));
       }
     }
-    // return minVersion = 0 and maxVersion = * if not available
-    if (!found)
-      return [ this.getBlocklistVersionRange(null) ];
+    // return minVersion = null and maxVersion = null if no specific versionRange
+    // elements were found
+    if (appVersions.length == 0)
+      appVersions.push(this.getBlocklistVersionRange(null));
     return appVersions;
   },
 
-/**
- * Retrieves a version range (e.g. minVersion and maxVersion) for a blocklist
- * versionRange element.
- * @param   versionRangeElement
- *          The versionRange blocklist element.
- * @returns A JS object with the following properties:
- *          "minVersion"  The minimum version in a version range (default = 0).
- *          "maxVersion"  The maximum version in a version range (default = *).
- */
+  /**
+   * Retrieves a version range (e.g. minVersion and maxVersion) for a blocklist
+   * versionRange element.
+   * @param   versionRangeElement
+   *          The versionRange blocklist element.
+   * @returns A JS object with the following properties:
+   *          "minVersion"  The minimum version in a version range (default = null).
+   *          "maxVersion"  The maximum version in a version range (default = null).
+   */
   getBlocklistVersionRange: function(versionRangeElement) {
-    var minVersion = "0";
-    var maxVersion = "*";
+    var minVersion = null;
+    var maxVersion = null;
     if (!versionRangeElement)
       return { minVersion: minVersion, maxVersion: maxVersion };
 
