@@ -1,4 +1,4 @@
-//@line 41 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/toolkit/components/viewconfig/content/config.js"
+//@line 41 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/toolkit/components/viewconfig/content/config.js"
 
 const nsIPrefLocalizedString = Components.interfaces.nsIPrefLocalizedString;
 const nsISupportsString = Components.interfaces.nsISupportsString;
@@ -330,10 +330,15 @@ function ShowPrefs()
   configTree.controllers.insertControllerAt(0, configController);
 
   document.getElementById("configDeck").setAttribute("selectedIndex", 1);
+  document.getElementById("configTreeKeyset").removeAttribute("disabled");
   if (!document.getElementById("showWarningNextTime").checked)
     gPrefBranch.setBoolPref("general.warnOnAboutConfig", false);
 
-  document.getElementById("textbox").focus();
+  var textbox = document.getElementById("textbox");
+  if (textbox.value)
+    // somebody seems to already have tried to apply a filter
+    FilterPrefs();
+  textbox.focus();
 }
 
 function onConfigUnload()
@@ -378,15 +383,6 @@ function FilterPrefs()
   view.treebox.invalidate();
   view.treebox.rowCountChanged(oldlen, gPrefView.length - oldlen);
   gotoPref(prefCol);
-  document.getElementById("button").disabled = !substring;
-}
-
-function ClearFilter(button)
-{
-  var textbox = document.getElementById("textbox");
-  textbox.value = "";
-  textbox.focus();
-  FilterPrefs();
 }
 
 function prefColSortFunction(x, y)
