@@ -1,4 +1,4 @@
-//@line 38 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/toolkit/content/inlineSpellCheckUI.js"
+//@line 38 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/toolkit/content/inlineSpellCheckUI.js"
 
 var InlineSpellCheckerUI = {
   mOverMisspelling: false,
@@ -165,7 +165,7 @@ var InlineSpellCheckerUI = {
 
     for (var i = 0; i < list.length; i ++) {
       // get the display name for this dictionary
-      isoStrArray = list[i].split("-");
+      isoStrArray = list[i].split(/[-_]/);
       var displayName = "";
       if (this.mLanguageBundle && isoStrArray[0]) {
         try {
